==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkCylinderSource.java <==
// java wrapper for vtkCylinderSource object
//

package vtk;
import vtk.*;

public class vtkCylinderSource extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetHeight_2(double id0);
  public void SetHeight(double id0)
    { SetHeight_2(id0); }

  private native double GetHeightMinValue_3();
  public double GetHeightMinValue()
    { return GetHeightMinValue_3(); }

  private native double GetHeightMaxValue_4();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_4(); }

  private native double GetHeight_5();
  public double GetHeight()
    { return GetHeight_5(); }

  private native void SetRadius_6(double id0);
  public void SetRadius(double id0)
    { SetRadius_6(id0); }

  private native double GetRadiusMinValue_7();
  public double GetRadiusMinValue()
    { return GetRadiusMinValue_7(); }

  private native double GetRadiusMaxValue_8();
  public double GetRadiusMaxValue()
    { return GetRadiusMaxValue_8(); }

  private native double GetRadius_9();
  public double GetRadius()
    { return GetRadius_9(); }

  private native void SetCenter_10(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_10(id0,id1,id2); }

  private native void SetCenter_11(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_11(id0); }

  private native double[] GetCenter_12();
  public double[] GetCenter()
    { return GetCenter_12(); }

  private native void SetResolution_13(int id0);
  public void SetResolution(int id0)
    { SetResolution_13(id0); }

  private native int GetResolutionMinValue_14();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_14(); }

  private native int GetResolutionMaxValue_15();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_15(); }

  private native int GetResolution_16();
  public int GetResolution()
    { return GetResolution_16(); }

  private native void SetCapping_17(int id0);
  public void SetCapping(int id0)
    { SetCapping_17(id0); }

  private native int GetCapping_18();
  public int GetCapping()
    { return GetCapping_18(); }

  private native void CappingOn_19();
  public void CappingOn()
    { CappingOn_19(); }

  private native void CappingOff_20();
  public void CappingOff()
    { CappingOff_20(); }

  private native void SetOutputPointsPrecision_21(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_21(id0); }

  private native int GetOutputPointsPrecision_22();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_22(); }

  public vtkCylinderSource() { super(); }

  public vtkCylinderSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv6h.pkg.tar.xz: vtk/vtkCylinderSource.java <==
// java wrapper for vtkCylinderSource object
//

package vtk;
import vtk.*;

public class vtkCylinderSource extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetHeight_2(double id0);
  public void SetHeight(double id0)
    { SetHeight_2(id0); }

  private native double GetHeightMinValue_3();
  public double GetHeightMinValue()
    { return GetHeightMinValue_3(); }

  private native double GetHeightMaxValue_4();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_4(); }

  private native double GetHeight_5();
  public double GetHeight()
    { return GetHeight_5(); }

  private native void SetRadius_6(double id0);
  public void SetRadius(double id0)
    { SetRadius_6(id0); }

  private native double GetRadiusMinValue_7();
  public double GetRadiusMinValue()
    { return GetRadiusMinValue_7(); }

  private native double GetRadiusMaxValue_8();
  public double GetRadiusMaxValue()
    { return GetRadiusMaxValue_8(); }

  private native double GetRadius_9();
  public double GetRadius()
    { return GetRadius_9(); }

  private native void SetCenter_10(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_10(id0,id1,id2); }

  private native void SetCenter_11(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_11(id0); }

  private native double[] GetCenter_12();
  public double[] GetCenter()
    { return GetCenter_12(); }

  private native void SetResolution_13(int id0);
  public void SetResolution(int id0)
    { SetResolution_13(id0); }

  private native int GetResolutionMinValue_14();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_14(); }

  private native int GetResolutionMaxValue_15();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_15(); }

  private native int GetResolution_16();
  public int GetResolution()
    { return GetResolution_16(); }

  private native void SetCapping_17(int id0);
  public void SetCapping(int id0)
    { SetCapping_17(id0); }

  private native int GetCapping_18();
  public int GetCapping()
    { return GetCapping_18(); }

  private native void CappingOn_19();
  public void CappingOn()
    { CappingOn_19(); }

  private native void CappingOff_20();
  public void CappingOff()
    { CappingOff_20(); }

  private native void SetOutputPointsPrecision_21(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_21(id0); }

  private native int GetOutputPointsPrecision_22();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_22(); }

  public vtkCylinderSource() { super(); }

  public vtkCylinderSource(long id) { super(id); }
  public native long   VTKInit();

}
